# Copyright (c) HashiCorp, Inc.
# SPDX-License-Identifier: MPL-2.0

# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: health.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'health.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0chealth.proto\x12\x06protos\"%\n\x12HealthCheckRequest\x12\x0f\n\x07service\x18\x01 \x01(\t\"\xa1\x01\n\x13HealthCheckResponse\x12\x39\n\x06status\x18\x01 \x01(\x0e\x32).protos.HealthCheckResponse.ServingStatus\"O\n\rServingStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SERVING\x10\x01\x12\x0f\n\x0bNOT_SERVING\x10\x02\x12\x13\n\x0fSERVICE_UNKNOWN\x10\x03\x32J\n\x06Health\x12@\n\x05\x43heck\x12\x1a.protos.HealthCheckRequest\x1a\x1b.protos.HealthCheckResponseB[ZYgithub.com/Proxmox-Cloud/terraform-provider-proxmox-cloud/internal/provider/protos;protosb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'health_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/Proxmox-Cloud/terraform-provider-proxmox-cloud/internal/provider/protos;protos'
  _globals['_HEALTHCHECKREQUEST']._serialized_start=24
  _globals['_HEALTHCHECKREQUEST']._serialized_end=61
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=64
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=225
  _globals['_HEALTHCHECKRESPONSE_SERVINGSTATUS']._serialized_start=146
  _globals['_HEALTHCHECKRESPONSE_SERVINGSTATUS']._serialized_end=225
  _globals['_HEALTH']._serialized_start=227
  _globals['_HEALTH']._serialized_end=301
# @@protoc_insertion_point(module_scope)



# Copyright (c) HashiCorp, Inc.
# SPDX-License-Identifier: MPL-2.0

# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

import pve_cloud_rpc.protos.cloud_pb2 as cloud__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in cloud_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class CloudServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetMasterKubeconfig = channel.unary_unary(
                '/protos.CloudService/GetMasterKubeconfig',
                request_serializer=cloud__pb2.GetKubeconfigRequest.SerializeToString,
                response_deserializer=cloud__pb2.GetKubeconfigResponse.FromString,
                _registered_method=True)
        self.GetClusterVars = channel.unary_unary(
                '/protos.CloudService/GetClusterVars',
                request_serializer=cloud__pb2.GetClusterVarsRequest.SerializeToString,
                response_deserializer=cloud__pb2.GetClusterVarsResponse.FromString,
                _registered_method=True)
        self.GetCloudSecret = channel.unary_unary(
                '/protos.CloudService/GetCloudSecret',
                request_serializer=cloud__pb2.GetCloudSecretRequest.SerializeToString,
                response_deserializer=cloud__pb2.GetCloudSecretResponse.FromString,
                _registered_method=True)
        self.GetCephAccess = channel.unary_unary(
                '/protos.CloudService/GetCephAccess',
                request_serializer=cloud__pb2.GetCephAccessRequest.SerializeToString,
                response_deserializer=cloud__pb2.GetCephAccessResponse.FromString,
                _registered_method=True)
        self.GetSshKey = channel.unary_unary(
                '/protos.CloudService/GetSshKey',
                request_serializer=cloud__pb2.GetSshKeyRequest.SerializeToString,
                response_deserializer=cloud__pb2.GetSshKeyResponse.FromString,
                _registered_method=True)
        self.GetProxmoxApi = channel.unary_unary(
                '/protos.CloudService/GetProxmoxApi',
                request_serializer=cloud__pb2.GetProxmoxApiRequest.SerializeToString,
                response_deserializer=cloud__pb2.GetProxmoxApiResponse.FromString,
                _registered_method=True)
        self.GetProxmoxHost = channel.unary_unary(
                '/protos.CloudService/GetProxmoxHost',
                request_serializer=cloud__pb2.GetProxmoxHostRequest.SerializeToString,
                response_deserializer=cloud__pb2.GetProxmoxHostResponse.FromString,
                _registered_method=True)
        self.GetPveInventory = channel.unary_unary(
                '/protos.CloudService/GetPveInventory',
                request_serializer=cloud__pb2.GetPveInventoryRequest.SerializeToString,
                response_deserializer=cloud__pb2.GetPveInventoryResponse.FromString,
                _registered_method=True)


class CloudServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetMasterKubeconfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetClusterVars(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCloudSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCephAccess(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSshKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProxmoxApi(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProxmoxHost(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPveInventory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CloudServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetMasterKubeconfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMasterKubeconfig,
                    request_deserializer=cloud__pb2.GetKubeconfigRequest.FromString,
                    response_serializer=cloud__pb2.GetKubeconfigResponse.SerializeToString,
            ),
            'GetClusterVars': grpc.unary_unary_rpc_method_handler(
                    servicer.GetClusterVars,
                    request_deserializer=cloud__pb2.GetClusterVarsRequest.FromString,
                    response_serializer=cloud__pb2.GetClusterVarsResponse.SerializeToString,
            ),
            'GetCloudSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCloudSecret,
                    request_deserializer=cloud__pb2.GetCloudSecretRequest.FromString,
                    response_serializer=cloud__pb2.GetCloudSecretResponse.SerializeToString,
            ),
            'GetCephAccess': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCephAccess,
                    request_deserializer=cloud__pb2.GetCephAccessRequest.FromString,
                    response_serializer=cloud__pb2.GetCephAccessResponse.SerializeToString,
            ),
            'GetSshKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSshKey,
                    request_deserializer=cloud__pb2.GetSshKeyRequest.FromString,
                    response_serializer=cloud__pb2.GetSshKeyResponse.SerializeToString,
            ),
            'GetProxmoxApi': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProxmoxApi,
                    request_deserializer=cloud__pb2.GetProxmoxApiRequest.FromString,
                    response_serializer=cloud__pb2.GetProxmoxApiResponse.SerializeToString,
            ),
            'GetProxmoxHost': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProxmoxHost,
                    request_deserializer=cloud__pb2.GetProxmoxHostRequest.FromString,
                    response_serializer=cloud__pb2.GetProxmoxHostResponse.SerializeToString,
            ),
            'GetPveInventory': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPveInventory,
                    request_deserializer=cloud__pb2.GetPveInventoryRequest.FromString,
                    response_serializer=cloud__pb2.GetPveInventoryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protos.CloudService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('protos.CloudService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class CloudService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetMasterKubeconfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protos.CloudService/GetMasterKubeconfig',
            cloud__pb2.GetKubeconfigRequest.SerializeToString,
            cloud__pb2.GetKubeconfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetClusterVars(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protos.CloudService/GetClusterVars',
            cloud__pb2.GetClusterVarsRequest.SerializeToString,
            cloud__pb2.GetClusterVarsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCloudSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protos.CloudService/GetCloudSecret',
            cloud__pb2.GetCloudSecretRequest.SerializeToString,
            cloud__pb2.GetCloudSecretResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCephAccess(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protos.CloudService/GetCephAccess',
            cloud__pb2.GetCephAccessRequest.SerializeToString,
            cloud__pb2.GetCephAccessResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSshKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protos.CloudService/GetSshKey',
            cloud__pb2.GetSshKeyRequest.SerializeToString,
            cloud__pb2.GetSshKeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetProxmoxApi(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protos.CloudService/GetProxmoxApi',
            cloud__pb2.GetProxmoxApiRequest.SerializeToString,
            cloud__pb2.GetProxmoxApiResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetProxmoxHost(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protos.CloudService/GetProxmoxHost',
            cloud__pb2.GetProxmoxHostRequest.SerializeToString,
            cloud__pb2.GetProxmoxHostResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPveInventory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protos.CloudService/GetPveInventory',
            cloud__pb2.GetPveInventoryRequest.SerializeToString,
            cloud__pb2.GetPveInventoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Copyright (c) HashiCorp, Inc.
# SPDX-License-Identifier: MPL-2.0

# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cloud.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cloud.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x63loud.proto\x12\x06protos\",\n\x16GetPveInventoryRequest\x12\x12\n\ntarget_pve\x18\x01 \x01(\t\"B\n\x17GetPveInventoryResponse\x12\x11\n\tinventory\x18\x01 \x01(\t\x12\x14\n\x0c\x63loud_domain\x18\x02 \x01(\t\"+\n\x15GetProxmoxHostRequest\x12\x12\n\ntarget_pve\x18\x01 \x01(\t\"*\n\x16GetProxmoxHostResponse\x12\x10\n\x08pve_host\x18\x01 \x01(\t\"\xa9\x01\n\x14GetProxmoxApiRequest\x12\x12\n\ntarget_pve\x18\x01 \x01(\t\x12\x10\n\x08\x61pi_path\x18\x02 \x01(\t\x12;\n\x08get_args\x18\x03 \x03(\x0b\x32).protos.GetProxmoxApiRequest.GetArgsEntry\x1a.\n\x0cGetArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"*\n\x15GetProxmoxApiResponse\x12\x11\n\tjson_resp\x18\x01 \x01(\t\"\x87\x01\n\x10GetSshKeyRequest\x12\x12\n\ntarget_pve\x18\x01 \x01(\t\x12\x32\n\x08key_type\x18\x02 \x01(\x0e\x32 .protos.GetSshKeyRequest.KeyType\"+\n\x07KeyType\x12\x0e\n\nAUTOMATION\x10\x00\x12\x10\n\x0cPVE_HOST_RSA\x10\x01\" \n\x11GetSshKeyResponse\x12\x0b\n\x03key\x18\x01 \x01(\t\"*\n\x14GetCephAccessRequest\x12\x12\n\ntarget_pve\x18\x01 \x01(\t\"A\n\x15GetCephAccessResponse\x12\x11\n\tceph_conf\x18\x01 \x01(\t\x12\x15\n\radmin_keyring\x18\x02 \x01(\t\">\n\x14GetKubeconfigRequest\x12\x12\n\ntarget_pve\x18\x01 \x01(\t\x12\x12\n\nstack_name\x18\x02 \x01(\t\"\'\n\x15GetKubeconfigResponse\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\t\"+\n\x15GetClusterVarsRequest\x12\x12\n\ntarget_pve\x18\x01 \x01(\t\"&\n\x16GetClusterVarsResponse\x12\x0c\n\x04vars\x18\x01 \x01(\t\"@\n\x15GetCloudSecretRequest\x12\x12\n\ntarget_pve\x18\x01 \x01(\t\x12\x13\n\x0bsecret_name\x18\x02 \x01(\t\"(\n\x16GetCloudSecretResponse\x12\x0e\n\x06secret\x18\x01 \x01(\t2\x87\x05\n\x0c\x43loudService\x12R\n\x13GetMasterKubeconfig\x12\x1c.protos.GetKubeconfigRequest\x1a\x1d.protos.GetKubeconfigResponse\x12O\n\x0eGetClusterVars\x12\x1d.protos.GetClusterVarsRequest\x1a\x1e.protos.GetClusterVarsResponse\x12O\n\x0eGetCloudSecret\x12\x1d.protos.GetCloudSecretRequest\x1a\x1e.protos.GetCloudSecretResponse\x12L\n\rGetCephAccess\x12\x1c.protos.GetCephAccessRequest\x1a\x1d.protos.GetCephAccessResponse\x12@\n\tGetSshKey\x12\x18.protos.GetSshKeyRequest\x1a\x19.protos.GetSshKeyResponse\x12L\n\rGetProxmoxApi\x12\x1c.protos.GetProxmoxApiRequest\x1a\x1d.protos.GetProxmoxApiResponse\x12O\n\x0eGetProxmoxHost\x12\x1d.protos.GetProxmoxHostRequest\x1a\x1e.protos.GetProxmoxHostResponse\x12R\n\x0fGetPveInventory\x12\x1e.protos.GetPveInventoryRequest\x1a\x1f.protos.GetPveInventoryResponseB[ZYgithub.com/Proxmox-Cloud/terraform-provider-proxmox-cloud/internal/provider/protos;protosb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cloud_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/Proxmox-Cloud/terraform-provider-proxmox-cloud/internal/provider/protos;protos'
  _globals['_GETPROXMOXAPIREQUEST_GETARGSENTRY']._loaded_options = None
  _globals['_GETPROXMOXAPIREQUEST_GETARGSENTRY']._serialized_options = b'8\001'
  _globals['_GETPVEINVENTORYREQUEST']._serialized_start=23
  _globals['_GETPVEINVENTORYREQUEST']._serialized_end=67
  _globals['_GETPVEINVENTORYRESPONSE']._serialized_start=69
  _globals['_GETPVEINVENTORYRESPONSE']._serialized_end=135
  _globals['_GETPROXMOXHOSTREQUEST']._serialized_start=137
  _globals['_GETPROXMOXHOSTREQUEST']._serialized_end=180
  _globals['_GETPROXMOXHOSTRESPONSE']._serialized_start=182
  _globals['_GETPROXMOXHOSTRESPONSE']._serialized_end=224
  _globals['_GETPROXMOXAPIREQUEST']._serialized_start=227
  _globals['_GETPROXMOXAPIREQUEST']._serialized_end=396
  _globals['_GETPROXMOXAPIREQUEST_GETARGSENTRY']._serialized_start=350
  _globals['_GETPROXMOXAPIREQUEST_GETARGSENTRY']._serialized_end=396
  _globals['_GETPROXMOXAPIRESPONSE']._serialized_start=398
  _globals['_GETPROXMOXAPIRESPONSE']._serialized_end=440
  _globals['_GETSSHKEYREQUEST']._serialized_start=443
  _globals['_GETSSHKEYREQUEST']._serialized_end=578
  _globals['_GETSSHKEYREQUEST_KEYTYPE']._serialized_start=535
  _globals['_GETSSHKEYREQUEST_KEYTYPE']._serialized_end=578
  _globals['_GETSSHKEYRESPONSE']._serialized_start=580
  _globals['_GETSSHKEYRESPONSE']._serialized_end=612
  _globals['_GETCEPHACCESSREQUEST']._serialized_start=614
  _globals['_GETCEPHACCESSREQUEST']._serialized_end=656
  _globals['_GETCEPHACCESSRESPONSE']._serialized_start=658
  _globals['_GETCEPHACCESSRESPONSE']._serialized_end=723
  _globals['_GETKUBECONFIGREQUEST']._serialized_start=725
  _globals['_GETKUBECONFIGREQUEST']._serialized_end=787
  _globals['_GETKUBECONFIGRESPONSE']._serialized_start=789
  _globals['_GETKUBECONFIGRESPONSE']._serialized_end=828
  _globals['_GETCLUSTERVARSREQUEST']._serialized_start=830
  _globals['_GETCLUSTERVARSREQUEST']._serialized_end=873
  _globals['_GETCLUSTERVARSRESPONSE']._serialized_start=875
  _globals['_GETCLUSTERVARSRESPONSE']._serialized_end=913
  _globals['_GETCLOUDSECRETREQUEST']._serialized_start=915
  _globals['_GETCLOUDSECRETREQUEST']._serialized_end=979
  _globals['_GETCLOUDSECRETRESPONSE']._serialized_start=981
  _globals['_GETCLOUDSECRETRESPONSE']._serialized_end=1021
  _globals['_CLOUDSERVICE']._serialized_start=1024
  _globals['_CLOUDSERVICE']._serialized_end=1671
# @@protoc_insertion_point(module_scope)
